<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Durum</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Her meşgul olduğunda kontrol et</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Durumu uzakta olarak ayarla</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Durumu görünmez olarak ayarla</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Tanımlama</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Değiştir</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Yeni tanımlama</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Durumu çok uzakta olarak ayarla</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n saniye</numerusform><numerusform>%n saniye</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Değiştirmeyin</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Davranış</translation>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Hareketsiz kalma</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Durum her yenilendiğinde</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation>&apos;Uzakta&apos; olarak değiştir</translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n dakika</numerusform><numerusform>% dakika</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation>&apos;Çok uzakta&apos; olarak değiştir</translation>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation>&apos;Görünmez&apos; olarak değiştir</translation>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation>&apos;Çevrimdışı&apos; olarak değiştir</translation>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation>Çevrimdışı olduktan sonra durumu değiştir</translation>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation>Durum tanımlaması aktif olmadığı zaman</translation>
    </message>
    <message>
        <source>Prepend</source>
        <translation>Başına ekle</translation>
    </message>
    <message>
        <source>Append</source>
        <translation>Sonuna ekle</translation>
    </message>
</context>
<context>
    <name>AutoawayConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Yenileme</translation>
    </message>
</context>
</TS>